/*global define*/
define(['dojo/_base/declare',
        'jimu/BaseWidget',
        'dojo/dom',
        'dojo/_base/array',
        'dojo/promise/all',
        'dojo/json',
        'esri/map',
        'esri/domUtils',
        'esri/graphic',
        'esri/graphicsUtils',
        'esri/geometry/Point',
        'esri/SpatialReference',
        'esri/tasks/GeometryService',
        'esri/tasks/Geoprocessor',
        'esri/tasks/FeatureSet',
        'esri/tasks/RelationParameters',
        'esri/Color',
        'esri/symbols/SimpleLineSymbol',
        'esri/symbols/SimpleMarkerSymbol',
        'jimu/utils',
        'dojo/_base/lang',
        'jimu/dijit/LoadingShelter',
        'dijit/_WidgetsInTemplateMixin',
        'esri/geometry/webMercatorUtils',
        'dojo/on',
        'dijit/form/TextBox',
        'dojo/domReady!'],


    function (declare, BaseWidget, dom, array, all, JSON, Map, domUtils, Graphic, graphicsUtils,
        Point, SpatialReference, GeometryService, Geoprocessor, FeatureSet, RelationParameters,
        Color, SimpleLineSymbol, SimpleMarkerSymbol, utils, lang, LoadingShelter,
        _WidgetsInTemplateMixin, webMercatorUtils, on) {

        //To create a widget, you need to derive from BaseWidget.
        return declare([BaseWidget, _WidgetsInTemplateMixin], {
            // Custom widget code goes here

            baseClass: 'jimu-widget-RefLocation',
            //this property is set by the framework when widget is loaded.
            name: 'RefLocation',
            label: "Reference Location",


            //methods to communication with app container:

            postCreate: function () {
                this.inherited(arguments);
                this.gp = new Geoprocessor("https://app.mdt.mt.gov/arcgis/rest/services/Testing/MakeCorridorPoint/GPServer/Make%20Route%20Event%20Layer");
            },

            _bindEvents: function () {
                this.own(on(this.returnpt, "click", lang.hitch(this, this._onreturnptClicked)));
                this.own(on(this.returnptclear, "click", lang.hitch(this, this._onclearClicked)));

            },

            startup: function () {
                this.inherited(arguments);
                this._bindEvents();
            },
            
            onClose: function () {
                this.mapClickEvt.remove();
            },

            executeGP: function (mp) {
                this.shelter.show();
                this.map.graphics.clear();
                var pointSymbol = new SimpleMarkerSymbol();
                pointSymbol.setSize(20);
                pointSymbol.setOutline(new SimpleLineSymbol(SimpleLineSymbol.STYLE_SOLID, new Color([255, 0, 0]), 1));
                pointSymbol.setColor(new Color([64, 43, 156, 1.5]));
                var graphic = new Graphic(mp.mapPoint, pointSymbol);
                var features = [graphic];
                var featureSet = new FeatureSet();
                featureSet.features = features;
                
                
                featureSet.fields = [
                    {
                        name: "OBJECTID",
                        alias: "OBJECTID",
                        type: "esriFieldTypeOID"
                    }, {
                        name: "Corridor",
                        alias: "Corridor",
                        type: "esriFieldTypeString",
                        length: 10
                    }, {
                        name: "MileOffset",
                        alias: "MileOffset",
                        type: "esriFieldTypeDouble"
                    }
                    ];

                var params = {
                		
                		"in_table": featureSet,
                		//"in_event_properties":
                		//"offset_field": "Milepost_and_Offset"
                };

                this.gp.submitJob(params, lang.hitch(this, this.processGP));

            },

            _onreturnptClicked: function () {
                var Corridor = this.CorridorTextBox.get("value"),
                    Offset = this.MeasureTextBox.get("value")
                    LocPoint =new Point(Corridor, Offset),
                    mp = {
                        mapPoint: LocPoint
                    };
                this.executeGP(mp);
            },


            _onclearClicked: function () {
                this.map.graphics.clear();
                this.CorridorTextBox.set("value", "");
                this.MeasureTextBox.set("value", "");
            },
          

        });
    });